@@ -69,13 +69,13 @@ IncidenceAttachment::~IncidenceAttachment()
     delete mPopupMenu;
 }
 
-void IncidenceAttachment::load(const KCalCore::Incidence::Ptr &incidence)
+void IncidenceAttachment::load(const KCalendarCore::Incidence::Ptr &incidence)
 {
     mLoadedIncidence = incidence;
     mAttachmentView->clear();
 
-    KCalCore::Attachment::List attachments = incidence->attachments();
-    for (KCalCore::Attachment::List::ConstIterator it = attachments.constBegin(),
+    KCalendarCore::Attachment::List attachments = incidence->attachments();
+    for (KCalendarCore::Attachment::List::ConstIterator it = attachments.constBegin(),
          end = attachments.constEnd();
          it != end; ++it) {
         new AttachmentIconItem((*it), mAttachmentView);
@@ -84,7 +84,7 @@ void IncidenceAttachment::load(const KCalCore::Incidence::Ptr &incidence)
     mWasDirty = false;
 }
 
-void IncidenceAttachment::save(const KCalCore::Incidence::Ptr &incidence)
+void IncidenceAttachment::save(const KCalendarCore::Incidence::Ptr &incidence)
 {
     incidence->clearAttachments();
 
@@ -92,8 +92,7 @@ void IncidenceAttachment::save(const KCalCore::Incidence::Ptr &incidence)
         QListWidgetItem *item = mAttachmentView->item(itemIndex);
         AttachmentIconItem *attitem = dynamic_cast<AttachmentIconItem *>(item);
         Q_ASSERT(item);
-        incidence->addAttachment(
-            KCalCore::Attachment::Ptr(new KCalCore::Attachment(*(attitem->attachment()))));
+        incidence->addAttachment(attitem->attachment());
     }
 }
 
@@ -104,18 +103,17 @@ bool IncidenceAttachment::isDirty() const
             return true;
         }
 
-        KCalCore::Attachment::List origAttachments = mLoadedIncidence->attachments();
+        KCalendarCore::Attachment::List origAttachments = mLoadedIncidence->attachments();
         for (int itemIndex = 0; itemIndex < mAttachmentView->count(); ++itemIndex) {
             QListWidgetItem *item = mAttachmentView->item(itemIndex);
             Q_ASSERT(dynamic_cast<AttachmentIconItem *>(item));
 
-            const KCalCore::Attachment::Ptr listAttachment
-                = static_cast<AttachmentIconItem *>(item)->attachment();
+            const KCalendarCore::Attachment listAttachment = static_cast<AttachmentIconItem *>(item)->attachment();
 
             for (int i = 0; i < origAttachments.count(); ++i) {
-                const KCalCore::Attachment::Ptr attachment = origAttachments.at(i);
+                const KCalendarCore::Attachment attachment = origAttachments.at(i);
 
-                if (*attachment == *listAttachment) {
+                if (attachment == listAttachment) {
                     origAttachments.remove(i);
                     break;
                 }
@@ -140,7 +138,7 @@ int IncidenceAttachment::attachmentCount() const
 void IncidenceAttachment::addAttachment()
 {
     QPointer<QObject> that(this);
-    AttachmentIconItem *item = new AttachmentIconItem(KCalCore::Attachment::Ptr(), mAttachmentView);
+    AttachmentIconItem *item = new AttachmentIconItem(KCalendarCore::Attachment(), mAttachmentView);
 
     QPointer<AttachmentEditDialog> dialog(new AttachmentEditDialog(item, mAttachmentView));
     dialog->setWindowTitle(i18nc("@title", "Add Attachment"));
@@ -189,8 +187,8 @@ void IncidenceAttachment::removeSelectedAttachments()
         if (it->isSelected()) {
             AttachmentIconItem *attitem = static_cast<AttachmentIconItem *>(it);
             if (attitem) {
-                KCalCore::Attachment::Ptr att = attitem->attachment();
-                labels << att->label();
+                const KCalendarCore::Attachment att = attitem->attachment();
+                labels << att.label();
                 selected << it;
             }
         }
@@ -200,7 +198,7 @@ void IncidenceAttachment::removeSelectedAttachments()
         return;
     }
 
-    QString labelsStr = labels.join(QStringLiteral("<nl/>"));
+    QString labelsStr = labels.join(QLatin1String("<nl/>"));
 
     if (KMessageBox::questionYesNo(
             nullptr,
@@ -236,25 +234,25 @@ void IncidenceAttachment::saveAttachment(QListWidgetItem *item)
     Q_ASSERT(dynamic_cast<AttachmentIconItem *>(item));
 
     AttachmentIconItem *attitem = static_cast<AttachmentIconItem *>(item);
-    if (!attitem->attachment()) {
+    if (attitem->attachment().isEmpty()) {
         return;
     }
 
-    KCalCore::Attachment::Ptr att = attitem->attachment();
+    KCalendarCore::Attachment att = attitem->attachment();
 
     // get the saveas file name
     const QString saveAsFile = QFileDialog::getSaveFileName(nullptr, i18nc("@title", "Save Attachment"),
-                                                      att->label());
+                                                            att.label());
 
     if (saveAsFile.isEmpty()) {
         return;
     }
 
     QUrl sourceUrl;
-    if (att->isUri()) {
-        sourceUrl = QUrl(att->uri());
+    if (att.isUri()) {
+        sourceUrl = QUrl(att.uri());
     } else {
-        sourceUrl = mAttachmentView->tempFileForAttachment(att);
+        sourceUrl = attitem->tempFileForAttachment();
     }
     // save the attachment url
     auto job = KIO::file_copy(sourceUrl, QUrl::fromLocalFile(saveAsFile));
@@ -278,18 +276,18 @@ void IncidenceAttachment::showAttachment(QListWidgetItem *item)
     Q_ASSERT(item);
     Q_ASSERT(dynamic_cast<AttachmentIconItem *>(item));
     AttachmentIconItem *attitem = static_cast<AttachmentIconItem *>(item);
-    if (!attitem->attachment()) {
+    if (attitem->attachment().isEmpty()) {
         return;
     }
 
-    KCalCore::Attachment::Ptr att = attitem->attachment();
-    if (att->isUri()) {
-        openURL(QUrl(att->uri()));
+    const KCalendarCore::Attachment att = attitem->attachment();
+    if (att.isUri()) {
+        openURL(QUrl(att.uri()));
     } else {
         KRun::RunFlags flags;
         flags |= KRun::DeleteTemporaryFiles;
         flags |= KRun::RunExecutables;
-        KRun::runUrl(mAttachmentView->tempFileForAttachment(att), att->mimeType(), nullptr, flags);
+        KRun::runUrl(attitem->tempFileForAttachment(), att.mimeType(), nullptr, flags);
     }
 }
 
@@ -344,7 +342,7 @@ void IncidenceAttachment::editSelectedAttachments()
             Q_ASSERT(dynamic_cast<AttachmentIconItem *>(item));
 
             AttachmentIconItem *attitem = static_cast<AttachmentIconItem *>(item);
-            if (!attitem->attachment()) {
+            if (attitem->attachment().isEmpty()) {
                 return;
             }
 
@@ -382,6 +380,9 @@ void IncidenceAttachment::slotSelectionChanged()
 
 void IncidenceAttachment::handlePasteOrDrop(const QMimeData *mimeData)
 {
+    if (!mimeData) {
+        return;
+    }
     QList<QUrl> urls;
     bool probablyWeHaveUris = false;
     QStringList labels;
@@ -497,14 +498,14 @@ void IncidenceAttachment::setupActions()
     KActionCollection *ac = new KActionCollection(this);
 //  ac->addAssociatedWidget( this );
 
-    mOpenAction = new QAction(QIcon::fromTheme(QStringLiteral("document-open")),i18nc("@action:inmenu open the attachment in a viewer",
-                                    "&Open"), this);
+    mOpenAction = new QAction(QIcon::fromTheme(QStringLiteral("document-open")), i18nc("@action:inmenu open the attachment in a viewer",
+                                                                                       "&Open"), this);
     connect(mOpenAction, &QAction::triggered, this, &IncidenceAttachment::showSelectedAttachments);
     ac->addAction(QStringLiteral("view"), mOpenAction);
     mPopupMenu->addAction(mOpenAction);
 
     mSaveAsAction = new QAction(QIcon::fromTheme(QStringLiteral("document-save-as")), i18nc("@action:inmenu save the attachment to a file",
-                                      "Save As..."), this);
+                                                                                            "Save As..."), this);
     connect(mSaveAsAction, &QAction::triggered, this,
             &IncidenceAttachment::saveSelectedAttachments);
     mPopupMenu->addAction(mSaveAsAction);
@@ -523,7 +524,7 @@ void IncidenceAttachment::setupActions()
 #endif
 
     mDeleteAction = new QAction(QIcon::fromTheme(QStringLiteral("list-remove")), i18nc("@action:inmenu remove the attachment",
-                                      "&Remove"), this);
+                                                                                       "&Remove"), this);
     connect(mDeleteAction, &QAction::triggered, this,
             &IncidenceAttachment::removeSelectedAttachments);
     ac->addAction(QStringLiteral("remove"), mDeleteAction);
@@ -532,7 +533,7 @@ void IncidenceAttachment::setupActions()
     mPopupMenu->addSeparator();
 
     mEditAction = new QAction(QIcon::fromTheme(QStringLiteral("document-properties")), i18nc("@action:inmenu show a dialog used to edit the attachment",
-                                    "&Properties..."), this);
+                                                                                             "&Properties..."), this);
     connect(mEditAction, &QAction::triggered, this, &IncidenceAttachment::editSelectedAttachments);
     ac->addAction(QStringLiteral("edit"), mEditAction);
     mPopupMenu->addAction(mEditAction);
@@ -555,19 +556,18 @@ void IncidenceAttachment::setupAttachmentIconView()
             &IncidenceAttachment::showContextMenu);
 
     QGridLayout *layout = new QGridLayout(mUi->mAttachmentViewPlaceHolder);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(mAttachmentView);
 }
 
-// void IncidenceAttachmentEditor::addAttachment( KCalCore::Attachment *attachment )
+// void IncidenceAttachmentEditor::addAttachment( KCalendarCore::Attachment *attachment )
 // {
 //   new AttachmentIconItem( attachment, mAttachmentView );
 // }
 
-void IncidenceAttachment::addDataAttachment(const QByteArray &data, const QString &mimeType,
-                                            const QString &label)
+void IncidenceAttachment::addDataAttachment(const QByteArray &data, const QString &mimeType, const QString &label)
 {
-    AttachmentIconItem *item = new AttachmentIconItem(KCalCore::Attachment::Ptr(), mAttachmentView);
+    AttachmentIconItem *item = new AttachmentIconItem(KCalendarCore::Attachment(), mAttachmentView);
 
     QString nlabel = label;
     if (mimeType == QLatin1String("message/rfc822")) {
@@ -590,22 +590,21 @@ void IncidenceAttachment::addDataAttachment(const QByteArray &data, const QStrin
     checkDirtyStatus();
 }
 
-void IncidenceAttachment::addUriAttachment(const QString &uri, const QString &mimeType,
-                                           const QString &label, bool inLine)
+void IncidenceAttachment::addUriAttachment(const QString &uri, const QString &mimeType, const QString &label, bool inLine)
 {
     if (!inLine) {
         AttachmentIconItem *item
-            = new AttachmentIconItem(KCalCore::Attachment::Ptr(), mAttachmentView);
+            = new AttachmentIconItem(KCalendarCore::Attachment(), mAttachmentView);
         item->setUri(uri);
         item->setLabel(label);
         if (mimeType.isEmpty()) {
-            if (uri.startsWith(QStringLiteral("uid:"))) {
+            if (uri.startsWith(QLatin1String("uid:"))) {
                 item->setMimeType(QStringLiteral("text/directory"));
-            } else if (uri.startsWith(QStringLiteral("kmail:"))) {
+            } else if (uri.startsWith(QLatin1String("kmail:"))) {
                 item->setMimeType(QStringLiteral("message/rfc822"));
-            } else if (uri.startsWith(QStringLiteral("urn:x-ical"))) {
+            } else if (uri.startsWith(QLatin1String("urn:x-ical"))) {
                 item->setMimeType(QStringLiteral("text/calendar"));
-            } else if (uri.startsWith(QStringLiteral("news:"))) {
+            } else if (uri.startsWith(QLatin1String("news:"))) {
                 item->setMimeType(QStringLiteral("message/news"));
             } else {
                 QMimeDatabase db;
