@@ -21,7 +21,7 @@
 #include "incidencecompletionpriority.h"
 #include "ui_dialogdesktop.h"
 
-#include <KCalCore/Todo>
+#include <KCalendarCore/Todo>
 
 using namespace IncidenceEditorNG;
 
@@ -67,11 +67,13 @@ IncidenceCompletionPriority::IncidenceCompletionPriority(Ui::EventOrTodoDesktop
     d->mUi->mCompletionPriorityWidget->hide();
     d->mUi->mTaskLabel->hide();
     const QFontMetrics metrics(d->mUi->mCompletedLabel->font());
-    d->mUi->mCompletedLabel->setMinimumWidth(metrics.width(QStringLiteral("100%")));
+    d->mUi->mCompletedLabel->setMinimumWidth(metrics.boundingRect(QStringLiteral("100%")).width());
     d->mUi->mTaskSeparator->hide();
 
-    connect(d->mUi->mCompletionSlider, QOverload<int>::of(&QSlider::valueChanged), this, [this](int val) { d->sliderValueChanged(val);});
-    connect(d->mUi->mPriorityCombo, QOverload< int>::of(&KComboBox::currentIndexChanged), this, &IncidenceCompletionPriority::checkDirtyStatus);
+    connect(d->mUi->mCompletionSlider, qOverload<int>(&QSlider::valueChanged), this, [this](int val) {
+        d->sliderValueChanged(val);
+    });
+    connect(d->mUi->mPriorityCombo, qOverload< int>(&QComboBox::currentIndexChanged), this, &IncidenceCompletionPriority::checkDirtyStatus);
 }
 
 IncidenceCompletionPriority::~IncidenceCompletionPriority()
@@ -79,13 +81,13 @@ IncidenceCompletionPriority::~IncidenceCompletionPriority()
     delete d;
 }
 
-void IncidenceCompletionPriority::load(const KCalCore::Incidence::Ptr &incidence)
+void IncidenceCompletionPriority::load(const KCalendarCore::Incidence::Ptr &incidence)
 {
     mLoadedIncidence = incidence;
 
     // TODO priority might be valid for other incidence types as well
     // only for Todos
-    KCalCore::Todo::Ptr todo = IncidenceCompletionPriority::incidence<KCalCore::Todo>();
+    KCalendarCore::Todo::Ptr todo = IncidenceCompletionPriority::incidence<KCalendarCore::Todo>();
     if (todo == nullptr) {
         mWasDirty = false;
         return;
@@ -108,11 +110,11 @@ void IncidenceCompletionPriority::load(const KCalCore::Incidence::Ptr &incidence
     mWasDirty = false;
 }
 
-void IncidenceCompletionPriority::save(const KCalCore::Incidence::Ptr &incidence)
+void IncidenceCompletionPriority::save(const KCalendarCore::Incidence::Ptr &incidence)
 {
     // TODO priority might be valid for other incidence types as well
     // only for Todos
-    KCalCore::Todo::Ptr todo = IncidenceCompletionPriority::incidence<KCalCore::Todo>(incidence);
+    KCalendarCore::Todo::Ptr todo = IncidenceCompletionPriority::incidence<KCalendarCore::Todo>(incidence);
     if (todo == nullptr) {
         return;
     }
@@ -129,7 +131,7 @@ void IncidenceCompletionPriority::save(const KCalCore::Incidence::Ptr &incidence
 
 bool IncidenceCompletionPriority::isDirty() const
 {
-    KCalCore::Todo::Ptr todo = IncidenceCompletionPriority::incidence<KCalCore::Todo>();
+    KCalendarCore::Todo::Ptr todo = IncidenceCompletionPriority::incidence<KCalendarCore::Todo>();
 
     if (!todo) {
         return false;
