@@ -46,8 +46,8 @@
 #include <Item>
 #include <Akonadi/Calendar/ETMCalendar>
 
-#include <KCalCore/ICalFormat>
-#include <KCalCore/MemoryCalendar>
+#include <KCalendarCore/ICalFormat>
+#include <KCalendarCore/MemoryCalendar>
 #include <KCalUtils/Stringify>
 
 #include <KMessageBox>
@@ -93,7 +93,7 @@ public:
 
 public:
     IncidenceDialogPrivate(Akonadi::IncidenceChanger *changer, IncidenceDialog *qq);
-    ~IncidenceDialogPrivate();
+    ~IncidenceDialogPrivate() override;
 
     /// General methods
     void handleAlarmCountChange(int newCount);
@@ -108,6 +108,7 @@ public:
     void updateButtonStatus(bool isDirty);
     void showMessage(const QString &text, KMessageWidget::MessageType type);
     void slotInvalidCollection();
+    void setCalendarCollection(const Akonadi::Collection &collection);
 
     /// ItemEditorUi methods
     bool containsPayloadIdentifiers(const QSet<QByteArray> &partIdentifiers) const override;
@@ -124,8 +125,7 @@ public:
 };
 }
 
-IncidenceDialogPrivate::IncidenceDialogPrivate(Akonadi::IncidenceChanger *changer,
-                                               IncidenceDialog *qq)
+IncidenceDialogPrivate::IncidenceDialogPrivate(Akonadi::IncidenceChanger *changer, IncidenceDialog *qq)
     : q_ptr(qq)
     , mUi(new Ui::EventOrTodoDesktop)
     , mCalSelector(new Akonadi::CollectionComboBox)
@@ -136,9 +136,10 @@ IncidenceDialogPrivate::IncidenceDialogPrivate(Akonadi::IncidenceChanger *change
 {
     Q_Q(IncidenceDialog);
     mUi->setupUi(q);
+    mUi->mMessageWidget->hide();
     QGridLayout *layout = new QGridLayout(mUi->mCalSelectorPlaceHolder);
     layout->setSpacing(0);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(mCalSelector);
     mCalSelector->setAccessRightsFilter(Akonadi::Collection::CanCreateItem);
     mUi->label->setBuddy(mCalSelector);
@@ -181,6 +182,11 @@ IncidenceDialogPrivate::IncidenceDialogPrivate(Akonadi::IncidenceChanger *change
     mIeResource = new IncidenceResource(mIeAttendee, mIeDateTime, mUi);
     mEditor->combine(mIeResource);
 
+    // Select calendar to last collection used, if valid; else select the default collection
+    const qint64 colId = IncidenceEditorNG::IncidenceEditorSettings::self()->lastSelectedFolder();
+    const Akonadi::Collection col(colId);
+    setCalendarCollection(col);
+
     q->connect(mEditor, SIGNAL(showMessage(QString,KMessageWidget::MessageType)),
                SLOT(showMessage(QString,KMessageWidget::MessageType)));
     q->connect(mEditor, SIGNAL(dirtyStatusChanged(bool)),
@@ -215,6 +221,23 @@ void IncidenceDialogPrivate::slotInvalidCollection()
     showMessage(i18n("Select a valid collection first."), KMessageWidget::Warning);
 }
 
+void IncidenceDialogPrivate::setCalendarCollection(const Akonadi::Collection &collection)
+{
+    if (collection.isValid()) {
+        mCalSelector->setDefaultCollection(collection);
+    } else {
+        // fallback to default collection
+        const qint64 defColId = CalendarSupport::KCalPrefs::instance()->defaultCalendarId();
+        const Akonadi::Collection defCol(defColId);
+        if (defCol.isValid()) {
+            mCalSelector->setDefaultCollection(defCol);
+        } else {
+            // Give up and use the first item in the selector
+            mCalSelector->setCurrentIndex(0);
+        }
+    }
+}
+
 void IncidenceDialogPrivate::showMessage(const QString &text, KMessageWidget::MessageType type)
 {
     mUi->mMessageWidget->setText(text);
@@ -278,11 +301,11 @@ QString IncidenceDialogPrivate::typeToString(const int type) const
 {
     // Do not translate.
     switch (type) {
-    case KCalCore::Incidence::TypeEvent:
+    case KCalendarCore::Incidence::TypeEvent:
         return QStringLiteral("Event");
-    case KCalCore::Incidence::TypeTodo:
+    case KCalendarCore::Incidence::TypeTodo:
         return QStringLiteral("Todo");
-    case KCalCore::Incidence::TypeJournal:
+    case KCalendarCore::Incidence::TypeJournal:
         return QStringLiteral("Journal");
     default:
         return QStringLiteral("Unknown");
@@ -293,7 +316,7 @@ void IncidenceDialogPrivate::loadTemplate(const QString &templateName)
 {
     Q_Q(IncidenceDialog);
 
-    KCalCore::MemoryCalendar::Ptr cal(new KCalCore::MemoryCalendar(QTimeZone::systemTimeZone()));
+    KCalendarCore::MemoryCalendar::Ptr cal(new KCalendarCore::MemoryCalendar(QTimeZone::systemTimeZone()));
 
     const QString fileName = QStandardPaths::locate(
         QStandardPaths::GenericDataLocation,
@@ -308,7 +331,7 @@ void IncidenceDialogPrivate::loadTemplate(const QString &templateName)
         return;
     }
 
-    KCalCore::ICalFormat format;
+    KCalendarCore::ICalFormat format;
     if (!format.load(cal, fileName)) {
         KMessageBox::error(
             q,
@@ -316,7 +339,7 @@ void IncidenceDialogPrivate::loadTemplate(const QString &templateName)
         return;
     }
 
-    KCalCore::Incidence::List incidences = cal->incidences();
+    KCalendarCore::Incidence::List incidences = cal->incidences();
     if (incidences.isEmpty()) {
         KMessageBox::error(
             q,
@@ -325,8 +348,8 @@ void IncidenceDialogPrivate::loadTemplate(const QString &templateName)
     }
 
     mIeDateTime->setActiveDate(QDate());
-    KCalCore::Incidence::Ptr newInc = KCalCore::Incidence::Ptr(incidences.first()->clone());
-    newInc->setUid(KCalCore::CalFormat::createUniqueId());
+    KCalendarCore::Incidence::Ptr newInc = KCalendarCore::Incidence::Ptr(incidences.first()->clone());
+    newInc->setUid(KCalendarCore::CalFormat::createUniqueId());
 
     // We add a custom property so that some fields aren't loaded, dates for example
     newInc->setCustomProperty(QByteArray("kdepim"), "isTemplate", QStringLiteral("true"));
@@ -359,28 +382,28 @@ void IncidenceDialogPrivate::saveTemplate(const QString &templateName)
 {
     Q_ASSERT(!templateName.isEmpty());
 
-    KCalCore::MemoryCalendar::Ptr cal(new KCalCore::MemoryCalendar(QTimeZone::systemTimeZone()));
+    KCalendarCore::MemoryCalendar::Ptr cal(new KCalendarCore::MemoryCalendar(QTimeZone::systemTimeZone()));
 
     switch (mEditor->type()) {
-    case KCalCore::Incidence::TypeEvent:
+    case KCalendarCore::Incidence::TypeEvent:
     {
-        KCalCore::Event::Ptr event(new KCalCore::Event());
+        KCalendarCore::Event::Ptr event(new KCalendarCore::Event());
         mEditor->save(event);
-        cal->addEvent(KCalCore::Event::Ptr(event->clone()));
+        cal->addEvent(KCalendarCore::Event::Ptr(event->clone()));
         break;
     }
-    case KCalCore::Incidence::TypeTodo:
+    case KCalendarCore::Incidence::TypeTodo:
     {
-        KCalCore::Todo::Ptr todo(new KCalCore::Todo);
+        KCalendarCore::Todo::Ptr todo(new KCalendarCore::Todo);
         mEditor->save(todo);
-        cal->addTodo(KCalCore::Todo::Ptr(todo->clone()));
+        cal->addTodo(KCalendarCore::Todo::Ptr(todo->clone()));
         break;
     }
-    case KCalCore::Incidence::TypeJournal:
+    case KCalendarCore::Incidence::TypeJournal:
     {
-        KCalCore::Journal::Ptr journal(new KCalCore::Journal);
+        KCalendarCore::Journal::Ptr journal(new KCalendarCore::Journal);
         mEditor->save(journal);
-        cal->addJournal(KCalCore::Journal::Ptr(journal->clone()));
+        cal->addJournal(KCalendarCore::Journal::Ptr(journal->clone()));
         break;
     }
     default:
@@ -393,7 +416,7 @@ void IncidenceDialogPrivate::saveTemplate(const QString &templateName)
     QDir().mkpath(fileName);
     fileName += templateName;
 
-    KCalCore::ICalFormat format;
+    KCalendarCore::ICalFormat format;
     format.save(cal, fileName);
 }
 
@@ -478,8 +501,7 @@ bool IncidenceDialogPrivate::containsPayloadIdentifiers(
     return partIdentifiers.contains(QByteArray("PLD:RFC822"));
 }
 
-void IncidenceDialogPrivate::handleItemSaveFail(EditorItemManager::SaveAction,
-                                                const QString &errorMessage)
+void IncidenceDialogPrivate::handleItemSaveFail(EditorItemManager::SaveAction, const QString &errorMessage)
 {
     Q_Q(IncidenceDialog);
 
@@ -512,10 +534,10 @@ void IncidenceDialogPrivate::handleItemSaveFinish(EditorItemManager::SaveAction
         const Akonadi::Item item = mItemManager->item();
         Q_ASSERT(item.isValid());
         Q_ASSERT(item.hasPayload());
-        Q_ASSERT(item.hasPayload<KCalCore::Incidence::Ptr>());
-        // Now the item is succesfull saved, reload it in the editor in order to
+        Q_ASSERT(item.hasPayload<KCalendarCore::Incidence::Ptr>());
+        // Now the item is successfully saved, reload it in the editor in order to
         // reset the dirty status of the editor.
-        mEditor->load(item.payload<KCalCore::Incidence::Ptr>());
+        mEditor->load(item.payload<KCalendarCore::Incidence::Ptr>());
         mEditor->load(item);
 
         // Set the buttons to a reasonable state as well (ok and apply should be
@@ -579,14 +601,14 @@ void IncidenceDialogPrivate::load(const Akonadi::Item &item)
     mEditor->load(CalendarSupport::incidence(item));
     mEditor->load(item);
 
-    const KCalCore::Incidence::Ptr incidence = CalendarSupport::incidence(item);
+    const KCalendarCore::Incidence::Ptr incidence = CalendarSupport::incidence(item);
     const QStringList allEmails = IncidenceEditorNG::EditorConfig::instance()->allEmails();
-    KCalCore::Attendee::Ptr me = incidence->attendeeByMails(allEmails);
+    const KCalendarCore::Attendee me = incidence->attendeeByMails(allEmails);
 
     if (incidence->attendeeCount() > 1     // >1 because you won't drink alone
-        && me && (me->status() == KCalCore::Attendee::NeedsAction
-                  || me->status() == KCalCore::Attendee::Tentative
-                  || me->status() == KCalCore::Attendee::InProcess)) {
+        && !me.isNull() && (me.status() == KCalendarCore::Attendee::NeedsAction
+                  || me.status() == KCalendarCore::Attendee::Tentative
+                  || me.status() == KCalendarCore::Attendee::InProcess)) {
         // Show the invitation bar: "You are invited [accept] [decline]"
         mUi->mInvitationBar->show();
     } else {
@@ -601,17 +623,17 @@ void IncidenceDialogPrivate::load(const Akonadi::Item &item)
         mCalSelector->setDefaultCollection(Akonadi::Collection(item.storageCollectionId()));
     }
 
-    if (!mCalSelector->mimeTypeFilter().contains(QStringLiteral("text/calendar"))
+    if (!mCalSelector->mimeTypeFilter().contains(QLatin1String("text/calendar"))
         || !mCalSelector->mimeTypeFilter().contains(incidence->mimeType())) {
         mCalSelector->setMimeTypeFilter(QStringList() << incidence->mimeType()
                                                       << QStringLiteral("text/calendar"));
     }
 
-    if (mEditor->type() == KCalCore::Incidence::TypeTodo) {
+    if (mEditor->type() == KCalendarCore::Incidence::TypeTodo) {
         q->setWindowIcon(QIcon::fromTheme(QStringLiteral("view-calendar-tasks")));
-    } else if (mEditor->type() == KCalCore::Incidence::TypeEvent) {
+    } else if (mEditor->type() == KCalendarCore::Incidence::TypeEvent) {
         q->setWindowIcon(QIcon::fromTheme(QStringLiteral("view-calendar-day")));
-    } else if (mEditor->type() == KCalCore::Incidence::TypeJournal) {
+    } else if (mEditor->type() == KCalendarCore::Incidence::TypeJournal) {
         q->setWindowIcon(QIcon::fromTheme(QStringLiteral("view-pim-journal")));
     }
 
@@ -629,10 +651,10 @@ void IncidenceDialogPrivate::load(const Akonadi::Item &item)
 
 Akonadi::Item IncidenceDialogPrivate::save(const Akonadi::Item &item)
 {
-    Q_ASSERT(mEditor->incidence<KCalCore::Incidence>());
+    Q_ASSERT(mEditor->incidence<KCalendarCore::Incidence>());
 
-    KCalCore::Incidence::Ptr incidenceInEditor = mEditor->incidence<KCalCore::Incidence>();
-    KCalCore::Incidence::Ptr newIncidence(incidenceInEditor->clone());
+    KCalendarCore::Incidence::Ptr incidenceInEditor = mEditor->incidence<KCalendarCore::Incidence>();
+    KCalendarCore::Incidence::Ptr newIncidence(incidenceInEditor->clone());
 
     Akonadi::Item result = item;
     result.setMimeType(newIncidence->mimeType());
@@ -646,18 +668,15 @@ Akonadi::Item IncidenceDialogPrivate::save(const Akonadi::Item &item)
     mEditor->save(newIncidence);
     mEditor->save(result);
 
-    // TODO: Remove this once we support moving of events/todo's
-    mCalSelector->setEnabled(false);
-
     // Make sure that we don't loose uid for existing incidence
-    newIncidence->setUid(mEditor->incidence<KCalCore::Incidence>()->uid());
+    newIncidence->setUid(mEditor->incidence<KCalendarCore::Incidence>()->uid());
 
     // Mark the incidence as changed
     if (mItem.isValid()) {
         newIncidence->setRevision(newIncidence->revision() + 1);
     }
 
-    result.setPayload<KCalCore::Incidence::Ptr>(newIncidence);
+    result.setPayload<KCalendarCore::Incidence::Ptr>(newIncidence);
     return result;
 }
 
@@ -677,8 +696,7 @@ void IncidenceDialogPrivate::reject(RejectReason reason, const QString &errorMes
 
 /// IncidenceDialog
 
-IncidenceDialog::IncidenceDialog(Akonadi::IncidenceChanger *changer, QWidget *parent,
-                                 Qt::WindowFlags flags)
+IncidenceDialog::IncidenceDialog(Akonadi::IncidenceChanger *changer, QWidget *parent, Qt::WindowFlags flags)
     : QDialog(parent, flags)
     , d_ptr(new IncidenceDialogPrivate(changer, this))
 {
@@ -763,8 +781,6 @@ void IncidenceDialog::load(const Akonadi::Item &item, const QDate &activeDate)
     d->mIeDateTime->setActiveDate(activeDate);
     if (item.isValid()) {   // We're editing
         d->mItemManager->load(item);
-        // TODO: Remove this once we support moving of events/todo's
-        d->mCalSelector->setEnabled(false);
     } else { // We're creating
         Q_ASSERT(d->hasSupportedPayload(item));
         d->load(item);
@@ -775,11 +791,7 @@ void IncidenceDialog::load(const Akonadi::Item &item, const QDate &activeDate)
 void IncidenceDialog::selectCollection(const Akonadi::Collection &collection)
 {
     Q_D(IncidenceDialog);
-    if (collection.isValid()) {
-        d->mCalSelector->setDefaultCollection(collection);
-    } else {
-        d->mCalSelector->setCurrentIndex(0);
-    }
+    d->setCalendarCollection(collection);
 }
 
 void IncidenceDialog::setIsCounterProposal(bool isCounterProposal)
@@ -826,7 +838,7 @@ void IncidenceDialog::slotButtonClicked(QAbstractButton *button)
             QDialog::reject(); // Discard current changes
         } else if (!d->isDirty()) {
             QDialog::reject(); // No pending changes, just close the dialog.
-        } // else { // the user wasn't finished editting after all }
+        } // else { // the user wasn't finished editing after all }
     } else if (d->mUi->buttonBox->button(QDialogButtonBox::RestoreDefaults)) {
         d->manageTemplates();
     } else {
@@ -834,6 +846,20 @@ void IncidenceDialog::slotButtonClicked(QAbstractButton *button)
     }
 }
 
+void IncidenceDialog::reject()
+{
+    Q_D(IncidenceDialog);
+    if (d->isDirty()
+        && KMessageBox::questionYesNo(
+            this,
+            i18nc("@info", "Do you really want to cancel?"),
+            i18nc("@title:window", "KOrganizer Confirmation")) == KMessageBox::Yes) {
+        QDialog::reject(); // Discard current changes
+    } else if (!d->isDirty()) {
+        QDialog::reject(); // No pending changes, just close the dialog.
+    }
+}
+
 void IncidenceDialog::closeEvent(QCloseEvent *event)
 {
     Q_D(IncidenceDialog);
